@@ -53,15 +53,23 @@
 #include "outputstream.h"
 #include "resolver.h"
 #include "seekable.h"
+#include "settings.h"
 #include "socket.h"
 #include "socketaddress.h"
 #include "socketaddressenumerator.h"
+#include "socketclient.h"
 #include "socketconnectable.h"
+#include "socketconnection.h"
+#include "socketlistener.h"
+#include "socketservice.h"
 #include "srvtarget.h"
+#include "tcpconnection.h"
+#include "threadedsocketservice.h"
 #include "themedicon.h"
 #include "volume.h"
 #include "volumemonitor.h"
 #include "desktopappinfo.h"
+#include "unixconnection.h"
 #include "unixinputstream.h"
 #include "unixoutputstream.h"
 
@@ -102,10 +110,20 @@ GType g_network_address_get_type(void);
 GType g_network_service_get_type(void);
 GType g_output_stream_get_type(void);
 GType g_resolver_get_type(void);
+GType g_settings_get_type(void);
 GType g_socket_get_type(void);
 GType g_socket_address_get_type(void);
 GType g_socket_address_enumerator_get_type(void);
+GType g_socket_client_get_type(void);
+GType g_socket_connection_get_type(void);
+GType g_socket_listener_get_type(void);
+GType g_socket_service_get_type(void);
+GType g_tcp_connection_get_type(void);
 GType g_themed_icon_get_type(void);
+GType g_threaded_socket_service_get_type(void);
+#ifndef G_OS_WIN32
+GType g_unix_connection_get_type(void);
+#endif //G_OS_WIN32
 #ifndef G_OS_WIN32
 GType g_unix_input_stream_get_type(void);
 #endif //G_OS_WIN32
@@ -117,6 +135,7 @@ GType g_volume_monitor_get_type(void);
 //Declarations of the *_error_quark() functions:
 
 GQuark g_io_error_quark(void);
+GQuark g_resolver_error_quark(void);
 } // extern "C"
 
 
@@ -154,10 +173,20 @@ namespace Gio {  class NetworkAddress_Class { public: static Glib::ObjectBase* w
 namespace Gio {  class NetworkService_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class OutputStream_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class Resolver_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gio {  class Settings_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class Socket_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class SocketAddress_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class SocketAddressEnumerator_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gio {  class SocketClient_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gio {  class SocketConnection_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gio {  class SocketListener_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gio {  class SocketService_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gio {  class TcpConnection_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class ThemedIcon_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gio {  class ThreadedSocketService_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+#ifndef G_OS_WIN32
+namespace Gio {  class UnixConnection_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+#endif //G_OS_WIN32
 #ifndef G_OS_WIN32
 namespace Gio {  class UnixInputStream_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 #endif //G_OS_WIN32
@@ -172,6 +201,7 @@ void wrap_init()
 {
   // Register Error domains:
   Glib::Error::register_domain(g_io_error_quark(), &Gio::Error::throw_func);
+  Glib::Error::register_domain(g_resolver_error_quark(), &Gio::ResolverError::throw_func);
 
 // Map gtypes to gtkmm wrapper-creation functions:
   Glib::wrap_register(g_app_launch_context_get_type(), &Gio::AppLaunchContext_Class::wrap_new);
@@ -206,10 +236,20 @@ void wrap_init()
   Glib::wrap_register(g_network_service_get_type(), &Gio::NetworkService_Class::wrap_new);
   Glib::wrap_register(g_output_stream_get_type(), &Gio::OutputStream_Class::wrap_new);
   Glib::wrap_register(g_resolver_get_type(), &Gio::Resolver_Class::wrap_new);
+  Glib::wrap_register(g_settings_get_type(), &Gio::Settings_Class::wrap_new);
   Glib::wrap_register(g_socket_get_type(), &Gio::Socket_Class::wrap_new);
   Glib::wrap_register(g_socket_address_get_type(), &Gio::SocketAddress_Class::wrap_new);
   Glib::wrap_register(g_socket_address_enumerator_get_type(), &Gio::SocketAddressEnumerator_Class::wrap_new);
+  Glib::wrap_register(g_socket_client_get_type(), &Gio::SocketClient_Class::wrap_new);
+  Glib::wrap_register(g_socket_connection_get_type(), &Gio::SocketConnection_Class::wrap_new);
+  Glib::wrap_register(g_socket_listener_get_type(), &Gio::SocketListener_Class::wrap_new);
+  Glib::wrap_register(g_socket_service_get_type(), &Gio::SocketService_Class::wrap_new);
+  Glib::wrap_register(g_tcp_connection_get_type(), &Gio::TcpConnection_Class::wrap_new);
   Glib::wrap_register(g_themed_icon_get_type(), &Gio::ThemedIcon_Class::wrap_new);
+  Glib::wrap_register(g_threaded_socket_service_get_type(), &Gio::ThreadedSocketService_Class::wrap_new);
+#ifndef G_OS_WIN32
+  Glib::wrap_register(g_unix_connection_get_type(), &Gio::UnixConnection_Class::wrap_new);
+#endif //G_OS_WIN32
 #ifndef G_OS_WIN32
   Glib::wrap_register(g_unix_input_stream_get_type(), &Gio::UnixInputStream_Class::wrap_new);
 #endif //G_OS_WIN32
@@ -251,10 +291,20 @@ void wrap_init()
   Gio::NetworkService::get_type();
   Gio::OutputStream::get_type();
   Gio::Resolver::get_type();
+  Gio::Settings::get_type();
   Gio::Socket::get_type();
   Gio::SocketAddress::get_type();
   Gio::SocketAddressEnumerator::get_type();
+  Gio::SocketClient::get_type();
+  Gio::SocketConnection::get_type();
+  Gio::SocketListener::get_type();
+  Gio::SocketService::get_type();
+  Gio::TcpConnection::get_type();
   Gio::ThemedIcon::get_type();
+  Gio::ThreadedSocketService::get_type();
+#ifndef G_OS_WIN32
+  Gio::UnixConnection::get_type();
+#endif //G_OS_WIN32
 #ifndef G_OS_WIN32
   Gio::UnixInputStream::get_type();
 #endif //G_OS_WIN32
